write_tree

Function write_tree 

pub fn write_tree(
    writer: impl Write,
    tree: &impl PrintTree,
    root: NodeId,
) -> Result<()>
Writes a debug representation of the computed layout to the writer, starting with the passed root node.